@@ -1,10 +1,7 @@
+from chocs.middleware.application_middleware import ApplicationMiddleware
+
 from .application import Application
-from .http_cookies import (
-    HttpCookie,
-    HttpCookieError,
-    HttpCookieJar,
-    HttpCookieSameSitePolicy,
-)
+from .http_cookies import HttpCookie, HttpCookieError, HttpCookieJar, HttpCookieSameSitePolicy
 from .http_error import HttpError, NotFoundError
 from .http_headers import HttpHeaders
 from .http_message import (
@@ -21,6 +18,5 @@ from .http_query_string import HttpQueryString
 from .http_request import HttpRequest
 from .http_response import HttpResponse
 from .http_status import HttpStatus
-from .router_middleware import RouterMiddleware
 from .routing import Route, Router
 from .wsgi import create_wsgi_handler, serve
